@@ -1,16 +1,9 @@
+#!/bin/bash
 # added 2014-11-14 by singh.janmejay
 # This file is part of the liblognorm project, released under ASL 2.0
-
-uname -a | grep "SunOS.*5.10"
-if [ $? -eq 0 ] ; then
-   echo platform: `uname -a`
-   echo This looks like solaris 10, we disable known-failing tests to
-   echo permit OpenCSW to build packages. However, this are real failurs
-   echo and so a fix should be done as soon as time permits.
-   exit 77
-fi
-export ln_opts='-oallowRegex'
 . $srcdir/exec.sh
+export ln_opts='-oallowRegex'
+no_solaris10
 
 test_def $0 "regex field with consume-group and return-group"
 set -x
