@@ -1,10 +1,11 @@
+#!/bin/bash
 # added 2015-07-15 by Rainer Gerhards
 # This checks if whitespace inside parser definitions is properly treated
 # This file is part of the liblognorm project, released under ASL 2.0
-
 . $srcdir/exec.sh
-
+no_solaris10
 test_def $0 "whitespace in parser definition"
+
 add_rule 'rule=:here is a number %   num:hexnumber   % in hex form'
 execute 'here is a number 0x1234 in hex form'
 assert_output_json_eq '{"num": "0x1234"}'
@@ -13,6 +14,4 @@ assert_output_json_eq '{"num": "0x1234"}'
 execute 'here is a number 0x1234in hex form'
 assert_output_json_eq '{ "originalmsg": "here is a number 0x1234in hex form", "unparsed-data": "0x1234in hex form" }'
 
-
 cleanup_tmp_files
-
