@@ -1,5 +1,7 @@
-#include <liblognorm.h>
+#include "config.h"
 #include <string.h>
+#include "liblognorm.h"
+#include "v1_liblognorm.h"
 
 int main() {
 	const char* str = "foo says hello!";
@@ -8,17 +10,14 @@ int main() {
 	ln_ctx ctx =  ln_initCtx();
 	int ret = 1;
 
-	ln_loadSample(ctx, "rule=:%from:word% says %msg:word%");
-	if (ln_normalize(ctx, str, strlen(str), &obj) == 0) {
+	ln_v1_loadSample(ctx, "rule=:%from:word% says %msg:word%");
+	if (ln_v1_normalize(ctx, str, strlen(str), &obj) == 0) {
 
-		from = json_object_object_get(obj, "from");
-		msg = json_object_object_get(obj, "msg");
+		json_object_object_get_ex(obj, "from", &from);
+		json_object_object_get_ex(obj, "msg", &msg);
 
 		ret = strcmp(json_object_get_string(from), "foo") ||
 			strcmp(json_object_get_string(msg), "hello!");
-
-		if (from != NULL) json_object_put(from);
-		if (msg != NULL) json_object_put(msg);
 	}
 
 	if (obj != NULL) json_object_put(obj);
